package game

import (
	"sort"

	"sirlab.de/go/knowyt/user"
)

func (gm *Game) GetQuotesInfoByUser(usr *user.User) *QuotesInfo {
	usrId := usr.GetId()
	return &QuotesInfo{Quotes: gm.getQuotesInfoByUserId(usrId)}
}

type ByCreated []Quote

func (quotes ByCreated) Len() int           { return len(quotes) }
func (quotes ByCreated) Less(a, b int) bool { return quotes[a].Created < quotes[b].Created }
func (quotes ByCreated) Swap(a, b int)      { quotes[a], quotes[b] = quotes[b], quotes[a] }

func (gm *Game) getQuotesInfoByUserId(usrId string) []Quote {
	gm.mu.Lock()
	defer gm.mu.Unlock()

	quotes := make([]Quote, 0)
	for _, quote := range gm.quotes {
		if quote.GetSourceId() == usrId {
			quotes = append(quotes, Quote{
				Id:      quote.GetId(),
				Quote:   quote.GetQuote(),
				Created: quote.GetCreated(),
			})
		}
	}
	sort.Sort(ByCreated(quotes))

	return quotes
}
